@@ -57,8 +57,8 @@ class Page(SortedDict):
             section.page = self
 
     def set_sections(self):
-        """Setup fields in subclasses"""
-        raise NotImplementedError('Implement in subclass')
+        """Setup fields in subclasses, by default page has not sections."""
+        pass
 
     def load(self, values):
         """Load values. @values must be a list of (name, value) pairs.
@@ -639,7 +639,8 @@ def _load_templates():
     first value will be template name and second will be template verbose
     name.
     """
-    mod = __import__(settings.TCMS_PAGES)
+    from django.utils.importlib import import_module
+    mod = import_module(settings.TCMS_PAGES)
 
     entries, dir_name = {}, dirname(mod.__file__)
     for path, subdirs, files  in walk(dir_name):
